summaryrefslogtreecommitdiff
path: root/test/parallel/test-cwd-enoent.js
diff options
context:
space:
mode:
authorImran Iqbal <imrani@ca.ibm.com>2015-09-16 11:36:55 -0400
committerMichael Dawson <michael_dawson@ca.ibm.com>2015-09-17 09:09:37 -0400
commit1cfee8ebcb27e1fdac1d0445a32c285a89f0c9ae (patch)
tree2148d379fd9e6399fa840a47dd317ff9bc038572 /test/parallel/test-cwd-enoent.js
parente4f2952341fc66b9e356448d6d0fbb0bc33678e8 (diff)
downloadandroid-node-v8-1cfee8ebcb27e1fdac1d0445a32c285a89f0c9ae.tar.gz
android-node-v8-1cfee8ebcb27e1fdac1d0445a32c285a89f0c9ae.tar.bz2
android-node-v8-1cfee8ebcb27e1fdac1d0445a32c285a89f0c9ae.zip
test: update cwd-enoent tests for AIX
On AIX you can not remove a directory that you are currently inside of as it results in an EBUSY error. "EBUSY: resource busy or locked". Updated the tests accordingly so that they are skipped on AIX. PR-URL: https://github.com/nodejs/node/pull/2909 Reviewed-By: Ben Noordhuis <ben@strongloop.com> Reviewed-By: Michael Dawson <michael_dawson@ca.ibm.com>
Diffstat (limited to 'test/parallel/test-cwd-enoent.js')
-rw-r--r--test/parallel/test-cwd-enoent.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/parallel/test-cwd-enoent.js b/test/parallel/test-cwd-enoent.js
index ebb62c1768..c6b3925ce3 100644
--- a/test/parallel/test-cwd-enoent.js
+++ b/test/parallel/test-cwd-enoent.js
@@ -4,8 +4,8 @@ var assert = require('assert');
var fs = require('fs');
var spawn = require('child_process').spawn;
-// Fails with EINVAL on SmartOS, EBUSY on Windows.
-if (process.platform === 'sunos' || common.isWindows) {
+// Fails with EINVAL on SmartOS, EBUSY on Windows, EBUSY on AIX.
+if (process.platform === 'sunos' || common.isWindows || common.isAix) {
console.log('1..0 # Skipped: cannot rmdir current working directory');
return;
}